@@ -13,7 +13,9 @@ signals:
 public:
     GoogleLatitude(QObject *parent = 0);
     void login(QString username, QString password);
-    void set(double latitude, double longitude, double accuracy=1000.);
+    void set(double la, double lo, double ac=1000.);
+    void freq(int f=120);
+    void reset();
     double get_lat() { return latitude; }
     double get_lon() { return longitude; }
     double get_acc() { return accuracy; }
@@ -28,11 +30,14 @@ private:
     double latitude;
     double longitude;
     double accuracy;
+    int interval;
     // stuff
     QNetworkAccessManager *worker;
     QUrl urllogin;
     QUrl urldologin;
     QUrl urlupdate;
+    qint64 lastupdate;
+    bool login_error;
 };
 
 #endif // GLATITUDE_H
