@@ -3,25 +3,26 @@
 
 #include <QtGui>
 #include <QtWebKit>
-#include <QtMaemo5>
 #include "glatitude.h"
 #include "gps.h"
+#ifdef Q_WS_MAEMO_5
+#include <QtMaemo5>
+#endif
 
 class LatitudeGUI : public QMainWindow {
     Q_OBJECT
 
-signals:
-    void newpos();
-
 public:
     LatitudeGUI(QMainWindow *parent = 0);
 
 private slots:
     void set();
+    void config();
     void latitude_OK();
     void latitude_ERROR();
     void save_user(QString);
     void save_pass(QString);
+    void save_freq(QString);
     void maps_login();
     void mode_buzz();
     void mode_latitude();
